Retrieve the standardization data for a specific method and version of a
test score class from the .std_versions registry. When method and/or
version are NULL, defaults are resolved via get_std_defaults().
Arguments
- scores
An
npsych_scoresobject (e.g.,MOCATOTS()).- method
A single string specifying the standardization method (e.g.,
"norms","regression"). IfNULL(default), the default method for the scores class is used.- version
A single string specifying the version name. If
NULL(default), the default version for the resolved method is used. Must beNULLwhenmethodisNULL.