List available standardization methods for npsych_scores
Source: R/list_std_methods.R
list_std_methods.RdGet methods that are available for a test class, or all available methods.
Arguments
- scores
A
npsych_scoresobject, such asMOCATOTS(). When the argument is supplied, only methods with registered versions for that specific test class are returned. When called via the.npsych_scoresmethod with a missing argument, all registered methods are returned.