Create an npsych_scores object, a validated numeric vector representing
neuropsychological test scores. This is the parent class for all
test-specific subclasses (e.g., MOCATOTS, TRAILA).
Arguments
- .data
Numeric vector of test scores. Values must fall within
rangeor match one of thecodes, or beNA.- label
A single string identifying the test (e.g.,
"MoCA","Trail Making Test Part A").- domain
A single string identifying the domain the test belongs to (e.g.,
"General Cognition","Language"). Defaults to an empty character vector.- short_descriptor
A short descriptor giving a little bit more information than the label. When available, the entry from the Researchers Data Dictionary; see rdd for more.
- range
A numeric vector of length 2 giving the minimum and maximum valid scores.
- codes
A named numeric vector of error/special codes (e.g.,
c("Not administered" = 88)). Defaults to an empty numeric vector.