A short description...
Arguments
- scores
A numeric vector of raw test scores.
- ...
Additional numeric vectors representing covariates, for example
age,educ,sex. These must be of length one or the same length asnpsych_scores, and named as columns in thelookup_tablefor the specifiedversion; useget_version_data({npsych_scores}, "norms", {version})$lookup_tableto inspect the table.- version
A single string specifying the version of the norms to use.