Standardize test scores using regression
Source:R/std_using_regression.R
std_using_regression-npsych_scores.RdA short description...
Arguments
- scores
A vector coercible to numeric, representing raw test scores.
- ...
Additional numeric covariates to be included in the regression model. Each covariate must be a numeric vector of length 1 or the same length as
npsych_scores, and must be named after a coefficient present in theversiondata; useget_version_data({npsych_scores}, "regression", {version})$coefsto inspect the coefficients.- version
A single string specifying the version of the regression model to use for standardization.